FieldVar

Struct FieldVar 

pub struct FieldVar(/* private fields */);
A wire of a relation: a plain index. Index 0 is FieldVar::ZERO, the wire every relation assigns the value zero.

Implementations

Source

impl FieldVar

pub const MAX_COUNT: usize

Maximum number of variables a relation can allocate.

pub const ZERO: Self

The distinguished zero wire, allocated and assigned by every relation.

pub const fn index(self) -> usize

The variable index.

pub const fn try_from_index(index: usize) -> Option<Self>

A variable from an index within the supported range.